Package: compareGroups
Type: Package
Title: Descriptive Analysis by Groups
Version: 4.10.2
Date: 2026-01-07
Depends: R (>= 3.5.0)
Imports: survival, tools, HardyWeinberg, rmarkdown, knitr, kableExtra,
        methods, chron, stats, writexl, flextable, officer, PMCMRplus,
        rmdformats, rstatix
Suggests: tcltk2, shiny, shinyBS, shinyjs, shinyjqui, shinythemes,
        shinyWidgets, shinydashboardPlus, DT, readxl, haven
Authors@R: c(
    person("Isaac", "Subirana", email ="isubirana@imim.es", role = c("aut", "cre"), 
      comment = c(ORCID = "0000-0003-1676-0197")
    ),
    person("Joan", "Salvador", email ="jvila@imim.es", role = c("ctb")
    )
    )
Maintainer: Isaac Subirana <isubirana@imim.es>
Description: Create data summaries for quality control, extensive reports for exploring data, as well as publication-ready univariate or bivariate tables in several formats (plain text, HTML,LaTeX, PDF, Word or Excel. Create figures to quickly visualise the distribution of your data (boxplots, barplots, normality-plots, etc.). Display statistics (mean, median, frequencies, incidences, etc.). Perform the appropriate tests (t-test, Analysis of variance, Kruskal-Wallis, Fisher, log-rank, ...) depending on the nature of the described variable (normal, non-normal or qualitative). Summarize genetic data (Single Nucleotide Polymorphisms) data displaying Allele Frequencies and performing Hardy-Weinberg Equilibrium tests among other typical statistics and tests for these kind of data.
License: GPL (>= 2)
URL: https://isubirana.github.io/compareGroups/index.html,
        https://isubirana.github.io/compareGroups/
LazyLoad: yes
Encoding: UTF-8
BuildVignettes: true
VignetteBuilder: knitr
RoxygenNote: 7.2.0
NeedsCompilation: no
Packaged: 2026-01-07 11:20:55 UTC; Usuari
Author: Isaac Subirana [aut, cre] (ORCID:
    <https://orcid.org/0000-0003-1676-0197>),
  Joan Salvador [ctb]
Repository: CRAN
Date/Publication: 2026-01-08 01:00:02 UTC
Built: R 4.6.0; ; 2026-05-01 01:26:55 UTC; unix
