importFrom(chron, chron)
importFrom(survival, Surv, survfit, survdiff, coxph)
importFrom(tools, texi2pdf)
importFrom(HardyWeinberg, HWChisqMat)
importFrom(rmarkdown, render, word_document)
importFrom(knitr, kable)
importFrom(grDevices, bmp, dev.new, dev.off, grey.colors, jpeg, pdf, png, rainbow, tiff)
importFrom(graphics, abline, barplot, box, boxplot, hist, legend, lines, mtext, par, plot, points, text, title)
importFrom(stats, oneway.test, TukeyHSD, anova, aov, as.formula, chisq.test, coef, confint, confint.default, 
           cor, cor.test, dnorm, fisher.test, formula, glm, kruskal.test, lm, median, na.pass, p.adjust, 
           pchisq, qqline, quantile, sd, shapiro.test, t.test, update, binom.test, qbinom, qt, binomial,
           qnorm, rbinom, uniroot, na.omit, relevel)
importFrom(utils, combn, read.csv, read.csv2, read.table, sessionInfo, write.table)
importFrom(methods, formalArgs)
importFrom(writexl, write_xlsx)
importFrom(officer, fp_border)
importFrom(flextable, add_header,align,as_chunk,as_flextable,as_grouped_data,as_i,as_paragraph,autofit,bg,bold,
           color,compose,fontsize,hline,hline_top,italic,merge_h,set_header_df,width,
           flextable, set_caption)
importFrom(kableExtra, add_footnote,add_header_above,add_indent,auto_index,cell_spec,collapse_rows,column_spec,
           footnote_marker_alphabet,footnote_marker_number,footnote_marker_symbol,group_rows,html_dependency_bsTable,
           html_dependency_kePrint,kable,kable_as_image,kable_as_xml,kable_styling,kableExtra_latex_packages,landscape,
           linebreak,magic_mirror,pack_rows,rmd_format,row_spec,save_kable,scroll_box,spec_angle,spec_color,
           spec_font_size,spec_popover,spec_tooltip,text_spec,usepackage_latex,xml_as_kable,xtable2kable)
importFrom(stats, model.frame)
importFrom(PMCMRplus, cuzickTest)
importFrom(rmdformats, html_clean)
importFrom(rstatix,games_howell_test)

export(
compareGroups,
summary.compareGroups,
print.summary.compareGroups,
varinfo,
varinfo.compareGroups,
createTable,
descrTable,
strataTable,
print.createTable,
summary.createTable,
print.summary.createTable,
export2latex,
export2latex.createTable,
export2latex.cbind.createTable,
export2csv,
export2html,
export2pdf,
export2md,
export2word,
export2xls,
cGroupsGUI,
cGroupsWUI,
report,
radiograph,
compareSNPs,
print.compareSNPs,
missingTable,
printTable,
getResults,
padjustCompareGroups
)


S3method("[",compareGroups)
S3method("[",createTable)
S3method("[",rbind.compareGroups)
S3method("[",rbind.createTable)
S3method("[",cbind.createTable)
S3method(print,compareGroups) 
S3method(plot,compareGroups)            
S3method(plot,createTable)            
S3method(print,createTable)          
S3method(print,summary.compareGroups)
S3method(print,summary.createTable)
S3method(print,cbind.createTable)
S3method(print,compareSNPs)
S3method(rbind,compareGroups)
S3method(rbind,createTable)
S3method(cbind,createTable)  
S3method(summary,compareGroups)  
S3method(summary,createTable)  
S3method(update,compareGroups)  
S3method(update,descrTable)  
S3method(varinfo,compareGroups)  
S3method(varinfo,createTable)  
S3method(export2latex,createTable) 
S3method(export2latex,cbind.createTable)



# not exported:
  # chisq.test2                
  # combn2                     
  # compare.i                  
  # descrip                    
  # flip                       
  # format2                    
  # signifdec.i                
  # signifdec                  
  # summ.i                     
  # table.i 
  # norm.plot
  # Others ...