**Select which variable indicates strata.**

Three choices are possible:

- **None:** No strata are considered.

- **Strata:** A variable must be selected. Only factors variables can be selected. The descriptives tables will be biuld within stratas defined by this variable.