If you want to apply the filter set in the first row table, click on this button. 

This filter will be applied in all the analyses (tables, plots, etc.).


**IMPORTANT NOTES**

- The selection will be applied in addition to the one that may be in the "Filter data" panel o nthe left side menu.

- You can filter several variables at once. Doing so, however, you are relating the selection by and "AND". Therefore, if you want to apply more sophysticated filter to the data set you must use the "Filter data" panel using R code. 