In this panel descriptives of SNPs ("Single Nucleotide Polymorphims") with appropriate statistics and tests for these genetic variants are displayed.

- `SNP`: SNP name.
- `Ntype`: Number of individuals with valid data.
- `MAF`: minor allele frequency.
- `Genotypes`: the three possible genotypes, or less if for some genotypes there are no observations.
- `Genotypes.p`: the corresponding genotypes percentages.
- `HWE.p`: Hardy Weinberg Equilibrium p-value.

If "group" is chosen, p-values to compare allele missingness by groups is computed.

Click on **Download** button from top bar to download the results table/s on a txt file.
