Set the type of your variables to be analysed as:

- **Normal:** mean (standard deviation), 

- **non-normal:** median [first quantile; third quartile]

- **categorical:** absolute frequencies (percentages). 

- **NA**: Select this options to test whether a continuous variable is normal or not by a Shapiro test. With this option, a numeric variable with five or less unique different values is also treated as categorical.

Appropiate statistical tests to compare among groups (if specified) are computed depending on the type (normal, non-normal or categorical).

To know more about the tests performed and the functions used in each case see the [published paper in JSS](https://www.jstatsoft.org/v57/i12/paper)

Use the "Format" from "Display" tab from left menu to change how statistics are displayed (e.g. to show or not the percentages, etc.)

