- **Report Confidence Intervals**: Indicate wheather to report descriptives (means, medians, frequencies or incidences), and or its confidence intervals.

- **Time for survival variables**: specify the time for which incidence is estimated for Surv variables. If it is left in blank, time corresponds to its median. 

- If no confidence intervals are reported, specify how to display the mean and standard deviation, the quantiles and frequencies.

- **Show variable format indicators**: write if you want to append some indications for continuous-normal, continuous non normal, categorical or survival variables (such as "Mean (SD)", or "N, %", etc.). 


