Type a selecting criteria to choose which individuals are included.

Also, you can select a subgroup of individuals for each variable. In any case, a logical expression in R language must 
be typed ("==" to compare, "&" to indicate "and", "|" to indicate "or" and "!" to indicate "not").
