This panel contains the loaded data in an interactive format (<a href="https://rstudio.github.io/DT/" target="_blank">see R <code>DT</code> package</a> for more information).

- Drag on columns to change the order of variables.

- By default, ten rows are shown. Navigate throught the rows using the bottom bar.

- Click on little arrows beside column name to sort rows ascending or descending by this variable.

- Click on **Download** just above the data table to download the data set in different formats such as CSV, Excel or PDF. 

- Click on **Column visibility** to hide or show columns/variables.

- Use the boxes just below the column names to select rows. To apply this selection you must click on **Update selection** from top bar. Note that filling boxes for several variables at the same time is equivalent to using "AND" operator. To apply more sophisticated selection criteria use the "Filter data" tab on left side bar menu. 

- Click on **View options** from top bar to change the font-size or to make the table wider or narrower.

**IMPORTANT**: If you use "Filter data" panel to select individuals, all selection made using data set little boxes is ignored.  



