Choose what to be displayed in the bivariate table:

- **ALL:** Descriptives for the entire data set.

- **p-overall:** p-value comparing the means, medians, proportions or incidence among groups. 

- **Descriptives:** Descriptives (means, medians, proportions, etc.) by groups.

- **p-trend:** p-value for trend. It is supposed that the groups are ordered.

- **OR/HR:** Odds Ratio or Hazard Ratio for binary or time-to-event response (grouping variable), respectively.

- **Avalaible:** Number of individuals with valid data for each variable and each groups.

- **NA category:** For categorical variables, the non-available data is considered as a new category.

- **Pairwise p-value:** When more than two groups are considered, p-values corresponding to 2 by 2 comparisons are performed taking into account multiple testing.

- **Simplify:** Empty categories (with no available data) are removed from the analyses.

