This panel contains the descriptive table with all variables selected, and all specification set in the left menu.

- Click on **Names/Labels** button from the top bar to show the correspondence between the names in the data set and their labels of the variables included in the descriptive table.

- Click on **Options** button from the top bar to change some aspects of the table such as the font-size, header color, etc.

- Click on **Save button** from the top bar to download the table in different formats: PDF, CSV, HTML, TXT (tab separated), Word or Excel. Note that stratified table cannot be downloaded either to CSV nor Excel.

- Click on **Go to variable information->** button at table bottom to flip to the reverse panel which contains some variable information, such as number of available data for each variable (and each group/strata), the type of variable (normal, non-normal, categorical, survival) and the selection criteria applied ('ALL' if no selection has been made). To return to descriptive table click on **<-Go to descriptive table** button.
