Select **"Own data"** to load your data in **SPSS**, **Excel**, **R**, **Stata** or **plain text** format from a file. Format is detected automatically depending on the uploaded file extension. 
Once the data is loaded satisfactory, click on "OK" button and the rest of the menu items on the left menu are shown.

Also you can select example data already present in the `compareGroups` package (**REGICOR**) and **SNPs** from `SNPassoc` package.

**Example data sets:**

- **REGICOR**: These data come from 3 different cross-sectional surveys of individuals representative of the population from a north-west Spanish province (Girona), REGICOR study. It contains 2294 observations on 21 variables such as age, sex, cholesterol profile hypertension, etc.)

- **SNPs**: A data.frame containing 35 selected SNPs and other clinical covariates for 110 cases and 47 controls in a case-control study.



**Notes:**

- It may be necessary to refresh the web page when loading a new data set.