A list of all variables from the data set will apear on the left side list. Click on the "x" beside each variable to remove them from the table. Or drag a variable to place it in a different order in the descripive table. If you click on the list window, non selected variables will appear which can be browsed and selected to be incorporated again in the selected variables. Once you have chosen which variables are displayed in the table and their order, press on "Update" button.

Click on "All" button to select all variables of the data set, and click on "None" if you want to deselect all variables. 

**Notes**

- When a new variable is created (using "Recode variables" panel), it is not visible in the selected variables. Click on "All" to select all variables included the new ones created.