Select a variable from the data set.

One of the following plots are displayed depending on the type of selected variables:

- **numeric**: Normality plots

- **categorical**: bar plot.

- **survival**: Kaplan-Meier cumulated survival curve with 95% confidence interval.

---------

**Notes:** 

- If a categorical variable is codified by numbers instead of levels, convert it to factor with `factor` function in the "recode variable" tab on left menu.

- Date variables are treated as numeric variable.





