Select 

- **None** to perform the analyses with the entire cohort without distinguishing groups.

- **Group**: to perform the analyses splitted by groups. Also, appropiate tests are performed to compare SNPs allele missingness distribution among groups.


