Choose the category you want to be hidden for categorical variables.

<br>

Additionally, in the "hide no" input text window you can type the category which represents "no" in the sense that the category named as indicated for all binary variables are hidden.
