Type the character which separates the alleles in the SNPs codification. This must be the same for all SNPs.
For example the genotype of a SNP is coded as "A/A","A/T","T/T", you must type "/".

Leave it in blank if the alleles are not separated by any character (for example "AA","AT","TT").

