**Select, "Single Nucleotid Polymorphics"**

You can only select variables which can be converted to SNPs ("Single Nucleotid Polymorphics"). 

Variables are converted to SNPs thru `SNPassoc` R package functions. 

