Set the Odds Ratio (OR) or Risk Ratio (RR) when response is binary, or Hazard Ratios (HR) for right censored response.

You can specify the reference category when computing the OR or HR for the categorical variables.

For continuous variables, the scale can be changed. This may be very useful for variables with a wide range such as total cholesterol, where it makes more sense to display the OR/HR for each 10 units of change rather than a single unit.